View source: R/Table-Functions.R
| extract_biased_items | R Documentation |
Extracts list of biased items from a dif_analysis object
extract_biased_items(dif.analysis)
dif.analysis |
Output from |
a list of vectors of column locations in item.data for the biased items identified by each DIF method.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.